Package: spqn
Title: Spatial quantile normalization
Version: 1.24.0
Description: The spqn package implements spatial quantile normalization (SpQN). This method was
	     developed to remove a mean-correlation relationship in correlation matrices built from
	     gene expression data. It can serve as pre-processing step prior to a co-expression
	     analysis.
Authors@R: c(person("Yi", "Wang", role = c("cre", "aut"), email = "yiwangthu5@gmail.com"),
	     person(c("Kasper", "Daniel"), "Hansen", role = "aut"))
License: Artistic-2.0
Imports: graphics, stats, utils, matrixStats
Depends: R (>= 4.0), ggplot2, ggridges, SummarizedExperiment,
        BiocGenerics
Suggests: BiocStyle, knitr, rmarkdown, tools, spqnData (>= 0.99.3),
        RUnit
VignetteBuilder: knitr
URL: https://github.com/hansenlab/spqn
BugReports: https://github.com/hansenlab/spqn/issues
biocViews: NetworkInference, GraphAndNetwork, Normalization
git_url: https://git.bioconductor.org/packages/spqn
git_branch: RELEASE_3_23
git_last_commit: 0813c60
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:59:40 UTC; biocbuild
Author: Yi Wang [cre, aut],
  Kasper Daniel Hansen [aut]
Maintainer: Yi Wang <yiwangthu5@gmail.com>
