import("ggplot2")
import("ggridges")
import("SummarizedExperiment")
importFrom("graphics", "abline", "legend", "lines", "plot", "points")
importFrom("stats", "IQR", "cor", "density", "qqplot", "sd")
importFrom("utils", "tail")
importFrom("matrixStats", "rowMedians")

export("plot_signal_condition_exp",
       "get_IQR_condition_exp",
       "qqplot_condition_exp",
       "normalize_correlation",
       "plot_IQR_condition_exp")
